@@ -12,37 +12,26 @@ def read(db_name: str):
 	_, json_exists, _, ddb_exists = utils.db_paths(db_name)
 	if not json_exists and not ddb_exists:
 		return None
-	# Wait in any write lock case, "need" or "has".
-	lock = locking.ReadLock(db_name)
-	try:
+	with locking.ReadLock(db_name):
 		return io_unsafe.read(db_name)
-	finally:
-		lock.unlock()
 
 
 def partial_read(db_name: str, key: str):
 	_, json_exists, _, ddb_exists = utils.db_paths(db_name)
 	if not json_exists and not ddb_exists:
 		return None
-	# Wait in any write lock case, "need" or "has".
-	lock = locking.ReadLock(db_name)
-	try:
+	with locking.ReadLock(db_name):
 		return io_unsafe.partial_read(db_name, key).key_value
-	finally:
-		lock.unlock()
 
 
-def write(db_name: str, db: dict):
+def write(db_name: str, data: dict):
 	"""
 		Ensures that writing only starts if there is no reading or writing in progress.
 	"""
 	dirname = os.path.dirname(f"{config.storage_directory}/{db_name}.any")
 	os.makedirs(dirname, exist_ok=True)
-	write_lock = locking.WriteLock(db_name)
-	try:
-		io_unsafe.write(db_name, db)
-	finally:
-		write_lock.unlock()
+	with locking.WriteLock(db_name):
+		io_unsafe.write(db_name, data)
 
 
 def delete(db_name: str):
@@ -52,11 +41,8 @@ def delete(db_name: str):
 	json_path, json_exists, ddb_path, ddb_exists = utils.db_paths(db_name)
 	if not json_exists and not ddb_exists:
 		return None
-	write_lock = locking.WriteLock(db_name)
-	try:
+	with locking.WriteLock(db_name):
 		if json_exists:
 			os.remove(json_path)
 		if ddb_exists:
 			os.remove(ddb_path)
-	finally:
-		write_lock.unlock()
